@@ -15,7 +15,7 @@ except ImportError: #python 3 zip is same as izip
     izip = zip
 
 from ..aid.sixing import *
-from .globaling import AUX, MOOT, INDENT_ADD, ScheduleNames
+from .globaling import AUX, MOOT, INDENT_ADD, ScheduleNames, TRANSIT, ActionSubContextNames
 from ..aid.odicting import odict
 
 from ..aid.classing import metaclassify, nonStringIterable
@@ -127,8 +127,8 @@ class Act(object):
         if not isinstance(self.actor, Actor): # Need to resolve .actor
             # .actor is currently unresolved name string for actor
             actor, inits, ioinits, parms = self.registrar.__fetch__(self.actor)
-            inits.update(self.inits or odict())
-            if self.prerefs: # preinits inits dict items
+
+            if self.prerefs: # preinits inits dict items  'do qua'
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('inits', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
@@ -137,14 +137,14 @@ class Act(object):
                     for field in fields:  # requires src pre inited
                         if field in src:  # only update if src has field
                             inits[field] = src[field]
+            inits.update(self.inits or odict())  # 'do cum' overrides qua, self.inits may be None
             if 'name' not in inits:
                 inits['name'] = self.actor  # as yet unresolved name string
             inits['store'] = self.frame.store
             inits['act'] = self
             self.actor = actor = actor(**inits) # instantiate and convert
 
-            parms.update(self.parms or odict())
-            if self.prerefs: # preinits parms dict items
+            if self.prerefs: # preinits parms dict items 'do from'
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('parms', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
@@ -153,24 +153,36 @@ class Act(object):
                     for field in fields:  # requires src pre inited
                         if field in src:  # only update if src has field
                             parms[field] = src[field]
+            parms.update(self.parms or odict())  # 'do with' overrides from, self.parms may be None
 
-            ioinits.update(self.ioinits or odict())  # self.ioinits 'do per'
-            if self.prerefs: # preinits ioinits dict items  'do for'
+            rioinits = odict(ioinits)  # save copy registry ioinits to keep ival iown
+            if self.prerefs:  # preinits ioinits dict items  'do for'
                 # each key is share src path, and value is list of src fields
-                for src, fields in self.prerefs.get('ioinits', {}).items():
-                    src = self.resolvePath(ipath=src, warn=True) # now a share
+                inode = (self.ioinits or  odict()).get('inode', ioinits.get('inode', ''))
+                for src, fields in self.prerefs.get('ioinits', {}).items():   # now resolve new src paths
+                    src = self.resolvePath(ipath=src, inode=inode, warn=True) # now a share
                     if not fields:  # default is use existing fields
                         fields = self._prepareSrcFields(src, fields)
-                    for field in fields:  # each src fld value pre inited with ipath
+                    for field in fields:  # assumes each src fld value pre inited with ipath
                         if field in src:  # only update if src has field
-                            ioinits[field] = src[field]  # clobbers ioinit odict() with ipath
+                            ioinits[field] = src[field] # clobbers ioinit odict() with ipath
+            ioinits.update(self.ioinits or odict())  # 'do per', self.ioinits may be None
+            for key, val in rioinits.items():  # restore registry ival iown defaults
+                if key in ioinits:  # check ipath overridden by for or per
+                    # if new val not mapping and old val is mapping
+                    if not isinstance(ioinits[key], Mapping) and isinstance(val, Mapping):
+                        val = val.copy()  # make copy so don't pollute registry
+                        val['ipath'] = ioinits[key]  # replace old ipath witn new
+                        ioinits[key] = val # restore default ival iown
+
             if ioinits:
-                iois = actor._initio(**ioinits)
+                inode, iois = actor._initio(ioinits)
                 if iois:
                     for key, ioi in iois.items():
-                        share = actor._resolvePath(   ipath=ioi['ipath'],
-                                                     ival=ioi.get('ival'),
-                                                     iown=ioi.get('iown'))
+                        share = actor._resolvePath(ipath=ioi['ipath'],
+                                                   ival=ioi.get('ival'),
+                                                   iown=ioi.get('iown'),
+                                                   inode=inode)
                         if actor._Parametric:
                             if key in parms:
                                 msg = "ResolveError: Parm and Ioi with same name"
@@ -193,7 +205,7 @@ class Act(object):
             self.parms.update(self.actor._resolve(**self.parms)) # resolve sub acts
             self.actor._prepare(**self.parms)
 
-    def resolvePath(self, ipath, ival=None, iown=None, warn=False):
+    def resolvePath(self, ipath, ival=None, iown=None, inode=None, warn=False):
         """
         Returns resolved Share or Node instance from ipath
         ipath may be path name of share or node
@@ -206,6 +218,8 @@ class Act(object):
         iown is optional ownership if True then overwrite if exists
                otherwise do not overwrite
 
+        inode is optional inode value for ipath used for ioinits
+
         if warn then will complain if the share is created.
 
         It allows for substitution into ipath of
@@ -233,8 +247,8 @@ class Act(object):
                 'me' indicates substitute the current framer, frame, or actor name
                 respectively.
 
-                'main' indicates substitute the current frame's main framer or main frame
-                name respectively obtained from
+                'main' indicates substitute the current .main.frame.name or
+                .main.frame.framer.name respectively obtained from aux .main link
 
 
 
@@ -264,59 +278,99 @@ class Act(object):
               self.actor is resolved
               self.actor.name is not empty
 
+        Any actor could have ioinits saved for them in their ._act  Act
+        If ionits exist then then an inode is part of the ioinits
+        Currently only the Do verb actors have ioinits. The inode is one of them.
+        The ioinits come from two sources. The registry and the do verb per and for
+        clauses
+
+        _act.ioinits are the do and per clauses
+        registry ioints are from the Actor.Ionints class variable
+
+        So inode parameter to Act.resolvePaths inidcates if for ioinit or not.
+        If inode None then ipath is not an ioinit and Otherwise even if "" then
+        ipath comes from ioinit and  should handle inode logic.
+        This would puts all the framer inode prepend
+        logic in one place and make it easier to climb the aux outline
+        or later add frame inodes
+
         """
         if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
-            if not ipath.startswith('.'): # not reconciled so do relative substitutions
-                parts = ipath.split('.')
-                if parts[0] == 'me':  #  framer inode relative addressing
-                    if not self.frame:
-                        raise excepting.ResolveError("ResolveError: Missing frame context"
-                                " to resolve relative pathname.", ipath, self,
-                                self.human, self.count)
-                    if not self.frame.framer:
-                        raise excepting.ResolveError("ResolveError: Missing framer context"
-                                " to resolve relative pathname.", ipath, self.frame,
-                                self.human, self.count)
-                    del parts[0]
+            parts = ipath.split('.')  # assume ipath is not empty
+            if parts and parts[0]:  # not empty and not absolute so do relative substitutions
+                if not self.frame:
+                    raise excepting.ResolveError("ResolveError: Missing frame context"
+                                             " to resolve relative pathname.", ipath, self,
+                                             self.human, self.count)
+                if not self.frame.framer:
+                    raise excepting.ResolveError("ResolveError: Missing framer context"
+                                                 " to resolve relative pathname.", ipath, self.frame,
+                                                 self.human, self.count)
 
-                    finode = ''  # inode of framer
-                    framer = self.frame.framer
-                    finode = framer.inode
-                    if framer.main:  # aux framer so special meaning of main or mine
-                        mainer = framer.main.framer  # main frame's framer eg main framer
-                        if finode == "main":  # replace finode with main framer inode
-                            finode = mainer.inode
-                            while finode == "main" and mainer.main:  # inode is main and has a main frame
-                                mainer = mainer.main.framer # walk up mainer links
-                                finode = mainer.inode  # substitude main for mainer.inode
-                        elif finode == "mine":  # don't prepend main framer inode
-                            finode = ""
-                        else:  # possibly prepend main framer inode if finode relative
-                            minode = framer.main.framer.inode
-                            minode = minode.rstrip('.')
-                            if not finode.startswith('.') and minode:  # prepend if relative
-                                finode = '.'.join([minode, finode])
-                    finode = finode.rstrip('.')
-                    if not finode:  # empty finode so use default actor relative
-                        finode = "framer.me.frame.me.actor.me"
-                    if finode:
-                        finparts = finode.split('.')
-                        if finparts:
-                            parts = finparts + parts
-                    ipath = '.'.join(parts)
+                framer = self.frame.framer
+                fparts = framer.inode.rstrip(".").split(".") if framer.inode else []
+                main = framer.main  # main frame
+                mainer = main.framer if main else None  # main frame's framer
+                # if mainer and not (absolute or framer relative)
+                # then fromer is aux framer so walk up mains processing inodes
+                # need to do this first because used by both inode and ipath logic below
+                while mainer and (not fparts or fparts[0] not in ("", "framer")):
+                    # four aux inode cases:
+                    # absolute: fparts[0] = "",
+                    # framer relative: fparts[0] == "framer",
+                    # empty: fparts == [],
+                    # me relative: fparts[0] == "me",
+                    # relative: otherwise
 
-            if not ipath.startswith('.'): # not reconciled so do relative substitutions
-                parts = ipath.split('.')
-                if parts[0] == 'framer':  #  relative addressing
-                    if not self.frame:
-                        raise excepting.ResolveError("ResolveError: Missing frame context"
-                            " to resolve relative pathname.", ipath, self,
-                                self.human, self.count)
-                    if not self.frame.framer:
-                        raise excepting.ResolveError("ResolveError: Missing framer context"
-                            " to resolve relative pathname.", ipath, self.frame,
-                                self.human, self.count)
+                    if fparts and fparts[0] == "me":
+                        del fparts[0]  # me relative
+                    else: # process over frame via inode
+                        while main and (not fparts or fparts[0] not in ("", "framer")):
+                            if main.inode:
+                                fparts = main.inode.rstrip(".").split(".") + fparts  # prepend
+                                if fparts and fparts[0] == "me":  # me relative
+                                    del fparts[0]
+                                    break  # skip any further over frames to main frame
+                            main = main.over  # walk up to over frame if any
+                        if fparts and fparts[0] in ("", "framer"):
+                            break
 
+                    if mainer.inode:
+                        fparts = mainer.inode.rstrip(".").split(".") + fparts  # prepend
+                    main = mainer.main  # main framer's main frame walk up one level
+                    mainer = main.framer if main else None  # walk up one level
+
+                if fparts and fparts[0] == "me" :
+                    del fparts[0]  # me not allowed as initial inode
+
+                # "" == ".".join([]) == ".".join([""])
+
+                # already know from above parts not empty and parts not absolute
+                if parts[0] not in ("framer", "me") and inode is not None:
+                    # prepend inode logic
+                    iparts = inode.rstrip(".").split(".") if inode else []
+                    if not iparts and not fparts:  # use default inode
+                        iparts = "framer.me.frame.me.actor.me".split(".")
+                    parts = iparts + parts  # prepend inode parts
+
+                # already know from above parts not empty
+                if parts[0] not in ("", "framer"):  # not absolute or framer relative
+                    if parts[0] == 'me':  # skip frame.inode processing
+                        del parts[0]  # parts could be empty now
+                    else:  # process frame.inode and walk up over if any
+                        frame = self.frame # start at current frame
+                        while frame and (parts[0] not in ("", "framer")):
+                            if frame.inode:
+                                parts = frame.inode.rstrip(".").split(".") + parts
+                            if parts[0] == "me":
+                                del parts[0]
+                                break  # skip any further over frames
+                            frame = frame.over
+                    if not parts or parts[0] not in ("", "framer"):
+                        parts = fparts + parts  # prepend fparts
+
+            if parts and parts[0]:  # not absolute so do relative substitutions
+                if parts[0] == 'framer':  #  framer relative addressing
                     if parts[1] == 'me': # current framer
                         parts[1] = self.frame.framer.name
                     elif parts[1] == 'main': # current main framer
@@ -356,8 +410,7 @@ class Act(object):
                                                self.human, self.count)
                                 parts[3:4] = nameToPath(self.actor.name).lstrip('.').rstrip('.').split('.')
 
-
-                ipath = '.'.join(parts)
+            ipath = '.'.join(parts)
 
             if not self.frame.store:
                 raise excepting.ResolveError("ResolveError: Missing store context"
@@ -568,23 +621,39 @@ class Actor(object):
 
         return parms
 
-    def _initio(self, inode='', **kwa):
+    def _initio(self, ioinits):
         """
-        Compute initializations for ioflo shares from inode and kwa arguments.
+        Compute initializations for ioflo shares from ioinits odict or item list
+        'inode' item in ioinits is special
+
         This implements a generic Actor interface protocol for associating the
         io data flow shares to the Actor.
 
         inode is the computed pathname string of the default share node
         where shares associated with the Actor instance may be placed when
-        relative addressing is used.
+        relative addressing is used. It is also the default data store context
+        for share references by Doer iois. The inode on an actor my be set
+        explicitly in the Ioinit class variable or in the actify (doify) decorator
+        or by the via clause of a Doer
 
-        The inode is computed as absolute, relative, or default.
-        The default inode is  'framer.me.frame.me.actor.me.'
-            This occurs if the framer inode (finode) is empty
+        The default inode is  'framer.me.frame.me.actor.me.' which is the case
+        when the passed in inode is empty.
+
+        If the inode is provided then if it is absolute, has a leading '.' then
+        it it left as is
+
+        If the inode is relative, has no leading '.' then relative substitution
+        rules apply.
+           If the inode is "me" or starts with "me." then replace the me with
+               the framer inode (frinode). Skip frame inode lookup
+
+           Otherwise apply prepend frame inode lookup
+
+            This occurs if the framer inode (frinode) is empty
                 (which occurs when the via clause is missing for the framer)
             and the ioinit inode parameter passed in is also empty
 
-        When a via clause exists for the framer then finode is not empty
+        When a via clause exists for the framer then frinode is not empty
             so the default is not used
             and the computed inode is either absolute or relative
 
@@ -613,7 +682,7 @@ class Actor(object):
         Missing init values from ipath, ival, iown will be assigned a
         default value as per the rules below:
 
-        For each kwa item (key, val)
+        For each ioinits item (key, val) besides the inode
             key is the name of the associated instance attribute or action parm.
             Extract ipath, ival, iown from val
 
@@ -659,47 +728,24 @@ class Actor(object):
                 init share with ival value using create ((change if not exist))
 
         """
+        ioinits = odict(ioinits)  # make copy also allows for item list as parameter
+        inode = ioinits.get('inode', '')
+
         if not isinstance(inode, basestring):
             raise ValueError("Nonstring inode arg '{0}'".format(inode))
 
-        finode = ''  # inode of framer
-        if self._act.frame.framer: # framer has been assigned
-            framer = self._act.frame.framer
-            finode = framer.inode  # could be empty
-            if framer.main:  # aux framer so special meaning of main or mine
-                mainer = framer.main.framer  # main frame's framer eg main framer
-                if finode == "main":  # replace finode with main framer inode
-                    finode = mainer.inode
-                    while finode == "main" and mainer.main:  # inode is main and has a main frame
-                        mainer = mainer.main.framer # walk up mainer links
-                        finode = mainer.inode  # substitude main for mainer.inode
-                elif finode == "mine":  # don't prepend main framer inode
-                    finode = ""  # effectively empty inode
-                else:  # otherwise just prepend main framer inode if relative
-                    minode = framer.main.framer.inode  # could be empty
-                    minode = minode.rstrip('.')
-                    if not finode.startswith('.') and minode:  # prepend if relative
-                        finode = '.'.join([minode, finode])
-
-        finode = finode.rstrip('.')
-
-        if not inode.startswith('.') and finode:  # not absolute and finode so prepend
-            if inode.startswith('me.') or inode == 'me':
-                raise ValueError("Invalid inode '{0}', first part == 'me'".format(inode))
-            inode = ".".join([finode, inode])
-
-        if not inode:  # empty or missing use default actor relative
-            inode = "framer.me.frame.me.actor.me."
-
-        if not inode.endswith('.'):
+        if inode and not inode.endswith('.'):
             inode = "{0}.".format(inode)
 
         iois = odict()
+        #ioi = odict(ipath=inode)  # create ioi for the inode not in kwa
+        #iois['inode'] = ioi  # inode path resolves first convenience when debugging
+        for key, val in ioinits.items():  # assumes keys are basestrings
+            if key == 'inode':  # skip inode
+                continue
 
-        for key, val in kwa.items():  # assumes keys are basestrings
             if val is None:  # use default assume no way to be inadvertent
                 val = ""  # empty string for val defaults ipath to same as key
-                #continue
 
             if isinstance(val, basestring):
                 ipath = val
@@ -722,27 +768,27 @@ class Actor(object):
                     else:
                         ival = odict(value=ival)
             else:
-                raise ValueError("Bad init kw arg '{0}'with Value '{1}'".format(key, val))
+                raise ValueError("Bad ioinit for key '{0}' with value '{1}'".format(key, val))
 
-            if ipath:
-                if not ipath.startswith('.'): # full path is inode joined to ipath
-                    if not(ipath.startswith('me.') or ipath == 'me'):  # do not override inode
-                        ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
-                    # any paths starting with me with have the framer inode (finode) substituted
-                    # in actor.resolvePath later this allows override of doer inode appendix
-            else: # empty ipath
-                ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
+            #if ipath:
+                #if not ipath.startswith('.'): # full path is inode joined to ipath
+                    #if not(ipath.startswith('me.') or ipath == 'me'):  # do not override inode
+                        #ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
+                    ## any paths starting with me with have the framer inode (frinode) substituted
+                    ## in act.resolvepath called by actor._resolvePath later
+                    ## this allows override of doer inode prepend
+            #else: # empty ipath
+                #ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
 
-            #if ipath.startswith('me.') or ipath == 'me':
-            #    raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
+            # inode is prepended in act.resolvePath
+
+            if not ipath:
+                ipath = key  # when ipath empty create default from key
 
             ioi = odict(ipath=ipath, ival=ival, iown=iown)
             iois[key] = ioi
 
-        ioi = odict(ipath=inode)  # create ioi for the inode
-        iois['inode'] = ioi
-
-        return iois # non-empty when _parametric
+        return (inode, iois)  # inode prepended in act.resolvePath
 
     def _prepare(self, **kwa):
         """ Base method to be overriden in sub classes. Perform post initio setup
@@ -754,7 +800,7 @@ class Actor(object):
         """
         pass
 
-    def _resolvePath(self, ipath, ival=None, iown=None, warn=False):
+    def _resolvePath(self, ipath, ival=None, iown=None, inode=None, warn=False):
         """ Returns resolved Share or Node instance from ipath
             Calls self._act.resolvePath()
             See doc string from Act.resolvePath for detailed description of
@@ -768,22 +814,26 @@ class Actor(object):
                 raise excepting.ResolveError("ResolveError: Missing act context"
                         " to resolve relative pathname.", ipath, self,
                         self._act.human, self._act.count)
-            ipath = self._act.resolvePath(ipath, ival, iown, warn)
+            ipath = self._act.resolvePath(ipath=ipath,
+                                          ival=ival,
+                                          iown=iown,
+                                          inode=inode,
+                                          warn=warn)
 
         return ipath
 
     def _prepareDstFields(self, srcFields, dst, dstFields):
         """
         Prepares  for a transfer of data
-        from srcFields to dstFields in dst
-           handles default conditions when fields are empty
-
-        srcFields is list of field names
-        dst is share
-        dstFields is list of field names
+           from srcFields
+           to dstFields in dst
+        Handles default conditions when fields are empty
+            srcFields is list of field names
+            dst is share
+            dstFields is list of field names
 
+        Ensure Builder.prepareDataDstFields is similar
         """
-
         if not dstFields: #no destinationField so use default rules
             if 'value' in dst:
                 dstFields = ['value'] #use value field
@@ -822,11 +872,11 @@ class Actor(object):
         Prepares and verifys a transfer of data
            from srcFields in src
            to dstFields in dst
-           handles default conditions when fields are empty
-
+        Handles default conditions when fields are empty
            src and dst are shares
            srcFields and dstFields are lists
 
+        Ensure Builder.prepareSrcDstFields is the same
         """
         if not srcFields: # empty source fields so assign defaults
             if src:
@@ -880,14 +930,17 @@ class Actor(object):
         return (srcFields, dstFields)
 
     def _verifyShareFields(self, share, fields):
-        """Verify that updating fields in share won't violate the
+        """
+        Verify that updating fields in share won't violate the
            condition that when a share has field == 'value'
            it will be the only field
 
            fields is list of field names
            share is  share
 
-           raises exception if condition would be violated
+        Raises exception if condition would be violated
+
+        Ensure Builder.verifyShareFields is same
         """
         if (len(fields) > 1) and ('value' in fields):
             msg = "ResolveError: Field = 'value' within fields = '{0}'".format(fields)
@@ -910,26 +963,38 @@ class Actor(object):
                                                      self._act.count)
 
 class Interrupter(Actor):
-    """Interrupter Actor Class
-       Interrupter is a base clase for all actor classes that interrupt normal precur
-       processing and result in a change in the frame or the frame processing.
+    """
+    Interrupter Actor Class
+    Interrupter is a base clase for all actor classes that interrupt normal precur
+    processing and result in a change in the frame or the frame processing.
 
-       This class must be subclassed. This is a convenience so can either use
-         isinstance to test
-
-       Specifically an Interrupter's action() method returns truthy when its action
-       interrupts the normal frame processing.
-
-       Examples are:
-       Transiters which interrupt by changing to a new frame
-       Suspenders which interrupt when the conditional aux condition is true and
-          further processing of the frame and sub frames is stopped
+    This class must be subclassed. This is a convenience so can either use
+      isinstance to test
 
+    Specifically an Interrupter's action() method returns truthy when its action
+    interrupts the normal frame processing.
 
+    Examples are:
+    Transiters which interrupt by changing to a new frame
+    Suspenders which interrupt when the conditional aux condition is true and
+       further processing of the frame and sub frames is stopped
     """
     def __init__(self,**kw ):
-        """Initialization method for instance. """
+        """
+        Initialization method for instance.
+
+        Inherited Attributes:
+            .name = name string for Actor variant in class Registry
+            .store = reference to shared data Store
+            ._act = reference to containing Act
+
+        Attributes:
+            ._tracts = list of references to transition acts for this Actor
+                transit sub-context of precur context during segue
+
+        """
         super(Interrupter,self).__init__(**kw)
+        self._tracts = []
 
 class Transiter(Interrupter):
     """Transiter Interrupter Class
@@ -976,8 +1041,10 @@ class Transiter(Interrupter):
         parms['far'] = far
 
         for act in needs:
-            act.act = self._act
+            act.act = self._act  # so act.resolve can ref self._act.frame.framer
             act.resolve()
+            self._tracts.extend(act.actor._tracts)
+            del act.actor._tracts[:]
 
         return parms
 
@@ -1014,6 +1081,9 @@ class Transiter(Interrupter):
         console.profuse("     enters: {0}\n".format([frame.name for frame in enters]))
         console.profuse("     reexens: {0}\n".format([frame.name for frame in reexens]))
 
+        for act in self._tracts:  # transit sub-context of segue precur
+            act()
+
         framer.exit(exits) #exit uncommon frames in near outline reversed in place
         framer.rexit(reexens[:]) #make copy since reversed in place
         framer.renter(reexens)
@@ -1066,6 +1136,8 @@ class Suspender(Interrupter):
         for act in needs:
             act.act = self._act
             act.resolve()
+            self._tracts.extend(act.actor._tracts)
+            del act.actor._tracts[:]
 
         deActParms = odict(aux=aux)
         deAct = SideAct( actor=self,
@@ -1111,6 +1183,9 @@ class Suspender(Interrupter):
                 human, framer.human, framer.elapsed)
             console.terse(msg)
 
+            for act in self._tracts:  # transit sub-context of cond aux segue precur
+                act()
+
             if aux.original:
                 aux.main = main  #assign aux's main to this frame
             aux.enterAll() #starts at aux.first frame
@@ -1187,20 +1262,22 @@ class MarkerUpdate(Marker):
         Builder at parse time when it encounters an NeedUpdate,
         creates the mark in the share and creates the appropriate MarkerUpdate
     """
-    def action(self, share, frame, **kwa):
+    def action(self, share, marker, **kwa):
         """ Update mark in share
-            Where share is reference to share and frame is frame name key of mark in
+            Where share is reference to share and marker is unique name key of mark in
                 share.marks odict
             Updates mark.stamp
 
-            only one mark per frame per share is needed
+            only one mark per marker per share is needed
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, frame, 'update' ))
+            self.name, share.name, marker, 'update' ))
 
-        mark = share.marks.get(frame)
+        mark = share.marks.get(marker)
         if mark:
-            mark.stamp = self.store.stamp #stamp when marker runs
+            mark.stamp = self.store.stamp  # update stamp when marker runs
+            if self._act.context == ActionSubContextNames[TRANSIT]:  # transit satisfied
+                mark.used = mark.stamp
 
     def _expose(self):
         """   """
@@ -1217,20 +1294,20 @@ class MarkerChange(Marker):
         Builder at parse time when it encounters a NeedChange,
         creates the mark in the share and creates the appropriate marker
     """
-    def action(self, share, frame, **kwa):
+    def action(self, share, marker, **kwa):
         """ Update mark in share
-            Where share is reference to share and frame is frame name key of mark in
+            Where share is reference to share and marker is unique name key of mark in
                 share.marks odict
             Updates mark.data
 
-            only one mark per frame per share is needed
+            only one mark per marker per share is needed
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, frame, 'change' ))
+            self.name, share.name, marker, 'change' ))
 
-        mark = share.marks.get(frame)
+        mark = share.marks.get(marker)
         if mark:
-            mark.data = storing.Data(share.items())
+            mark.data = storing.Data(share.items())  # set date when marker runs
 
     def _expose(self):
         """   """
